@@ -1,13 +1,14 @@
 package App::wordlist;
 
-our $DATE = '2018-03-19'; # DATE
-our $VERSION = '0.265'; # VERSION
+our $DATE = '2018-03-22'; # DATE
+our $VERSION = '0.266'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 use List::Util qw(shuffle);
+use WordList::Namespace qw(is_actual_wordlist_module);
 
 our %SPEC;
 
@@ -46,14 +47,13 @@ sub _list_installed {
         });
     my @res;
     for my $wl0 (sort keys %$mods) {
+        next unless is_actual_wordlist_module($wl0);
         (my $wl = $wl0) =~ s/\AWordList:://;
 
         my $type;
         if ($wl =~ /^(Base|MetaSyntactic)\z/) {
             # just a base class
             next;
-        } elsif ($wl =~ s/^Base:://) {
-            $type = 'Base';
         } elsif ($wl =~ s/^MetaSyntactic:://) {
             $type = 'MetaSyntactic';
         } elsif ($wl =~ s/^Char:://) {
@@ -474,7 +474,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.265 of App::wordlist (from Perl distribution App-wordlist), released on 2018-03-19.
+This document describes version 0.266 of App::wordlist (from Perl distribution App-wordlist), released on 2018-03-22.
 
 =head1 SYNOPSIS
 
